@@ -4,11 +4,15 @@ from sqlbean.db.mc_connection import mc
 from marshal import dumps, loads
 from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create,save
 from array import array
+from datetime import datetime
 
 def model_dumps(self):
     value = []
     for i in self._fields:
-        value.append(self.__dict__.get(i, None))
+        v = self.__dict__.get(i, None)
+        if type(v) is datetime:
+            v = v.strftime("%Y-%m-%d %H:%M:%S")             
+        value.append(v)
     value = dumps(tuple(value))
     return value 
 
