@@ -1,6 +1,6 @@
 #coding:utf-8
 from sqlbean.db.query import Query, escape
-from sqlbean.metamodel import cache, lower_name, ModelBase,get_or_create
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save
 
 class Model(object):
     '''
@@ -125,6 +125,7 @@ class Model(object):
 
         cursor = Query.raw_sql(query, values, self.db)
 
+    save = save
 
     def _new_save(self):
         'Uses SQL INSERT to create new record'
@@ -190,14 +191,6 @@ class Model(object):
         values = kwds.values()+[getattr(self, self.Meta.pk)]
         Query.raw_sql(query, values, self.db)
 
-    def save(self):
-        if self._new_record:
-            self._set_default()
-            self._new_save()
-            self._new_record = False
-        else:
-            self._update()
-        return self
 
     @classmethod
     def where(cls, *args, **kwargs):
@@ -258,14 +251,6 @@ class Model(object):
         finally:
             db.b_commit = True
 
-    def save(self):
-        if self._new_record:
-            self._set_default()
-            self._new_save()
-            self._new_record = False
-        else:
-            self._update()
-        return self
 
     get_or_create = get_or_create
 
